Do not use insecure or weak cryptographic algorithms. For example, the Data Encryption Standard (DES) encryption
algorithm is considered highly insecure

Do not use Object.equals() to compare cryptographic keys

Cryptographic keys should never be serialized